=====
Trove
=====

.. image:: http://governance.openstack.org/badges/trove.svg
    :target: http://governance.openstack.org/reference/tags/index.html

Trove is Database as a Service for OpenStack.

Getting Started
---------------

If you'd like to run from the master branch, you can clone the git repo:

    git clone https://github.com/openstack/trove


* Wiki: https://wiki.openstack.org/wiki/Trove
* Developer Docs: http://docs.openstack.org/developer/trove

You can raise bugs here: https://bugs.launchpad.net/trove

Python client
-------------
https://git.openstack.org/cgit/openstack/python-troveclient

References
----------

* Installation docs:
  http://docs.openstack.org/developer/trove/dev/install.html
* Manual installation docs:
  http://docs.openstack.org/developer/trove/dev/manual_install.html
* Build guest image:
  http://docs.openstack.org/developer/trove/dev/building_guest_images.html
